@@ -6,22 +6,24 @@ import pwndbg.commands
 import pwndbg.commands.telescope
 import pwndbg.disasm
 
-parser = argparse.ArgumentParser(
-    description='Prints determined arguments for call instruction.'
-)
-parser.add_argument('-f', '--force', action='store_true', help='Force displaying of all arguments.')
+parser = argparse.ArgumentParser(description="Prints determined arguments for call instruction.")
+parser.add_argument("-f", "--force", action="store_true", help="Force displaying of all arguments.")
 
 
 @pwndbg.commands.ArgparsedCommand(parser)
 @pwndbg.commands.OnlyWhenRunning
-def dumpargs(force=False):
+def dumpargs(force=False) -> None:
     args = (not force and call_args()) or all_args()
 
     if args:
-        print('\n'.join(args))
+        print("\n".join(args))
     else:
         print("Couldn't resolve call arguments from registers.")
-        print("Detected ABI: {} ({} bit) either doesn't pass arguments through registers or is not implemented. Maybe they are passed on the stack?".format(pwndbg.arch.current, pwndbg.arch.ptrsize*8))
+        print(
+            "Detected ABI: {} ({} bit) either doesn't pass arguments through registers or is not implemented. Maybe they are passed on the stack?".format(
+                pwndbg.gdblib.arch.current, pwndbg.gdblib.arch.ptrsize * 8
+            )
+        )
 
 
 def call_args():
@@ -33,9 +35,9 @@ def call_args():
     results = []
 
     for arg, value in pwndbg.arguments.get(pwndbg.disasm.one()):
-        code   = False if arg.type == 'char' else True
+        code = arg.type != "char"
         pretty = pwndbg.chain.format(value, code=code)
-        results.append('        %-10s %s' % (arg.name+':', pretty))
+        results.append("        %-10s %s" % (arg.name + ":", pretty))
 
     return results
 
@@ -47,6 +49,6 @@ def all_args():
     results = []
 
     for name, value in pwndbg.arguments.arguments():
-        results.append('%4s = %s' % (name, pwndbg.chain.format(value)))
+        results.append("%4s = %s" % (name, pwndbg.chain.format(value)))
 
     return results
