@@ -1,43 +1,46 @@
 import gdb
-from capstone import *
+from capstone import *  # noqa: F403
 
-import pwndbg.memoize
-import pwndbg.symbol
+import pwndbg.gdblib.symbol
+import pwndbg.lib.memoize
 
 debug = False
 
-groups = {v:k for k,v in globals().items() if k.startswith('CS_GRP_')}
-ops    = {v:k for k,v in globals().items() if k.startswith('CS_OP_')}
-access = {v:k for k,v in globals().items() if k.startswith('CS_AC_')}
+groups = {v: k for k, v in globals().items() if k.startswith("CS_GRP_")}
+ops = {v: k for k, v in globals().items() if k.startswith("CS_OP_")}
+access = {v: k for k, v in globals().items() if k.startswith("CS_AC_")}
 
 for value1, name1 in dict(access).items():
     for value2, name2 in dict(access).items():
-        access.setdefault(value1 | value2, '%s | %s' % (name1, name2))
+        # novermin
+        access.setdefault(value1 | value2, "%s | %s" % (name1, name2))
 
 
 class DisassemblyAssistant:
     # Registry of all instances, {architecture: instance}
     assistants = {}
 
-    def __init__(self, architecture):
+    def __init__(self, architecture) -> None:
         if architecture is not None:
             self.assistants[architecture] = self
 
         self.op_handlers = {
             CS_OP_IMM: self.immediate,
             CS_OP_REG: self.register,
-            CS_OP_MEM: self.memory
+            CS_OP_MEM: self.memory,
         }
 
         self.op_names = {
             CS_OP_IMM: self.immediate_sz,
             CS_OP_REG: self.register_sz,
-            CS_OP_MEM: self.memory_sz
+            CS_OP_MEM: self.memory_sz,
         }
 
     @staticmethod
-    def enhance(instruction):
-        enhancer = DisassemblyAssistant.assistants.get(pwndbg.arch.current, generic_assistant)
+    def enhance(instruction) -> None:
+        enhancer = DisassemblyAssistant.assistants.get(
+            pwndbg.gdblib.arch.current, generic_assistant
+        )
         enhancer.enhance_operands(instruction)
         enhancer.enhance_symbol(instruction)
         enhancer.enhance_conditional(instruction)
@@ -46,7 +49,7 @@ class DisassemblyAssistant:
         if debug:
             print(enhancer.dump(instruction))
 
-    def enhance_conditional(self, instruction):
+    def enhance_conditional(self, instruction) -> None:
         """
         Adds a ``condition`` field to the instruction.
 
@@ -68,10 +71,10 @@ class DisassemblyAssistant:
 
         instruction.condition = c
 
-    def condition(self, instruction):
+    def condition(self, instruction) -> bool:
         return False
 
-    def enhance_next(self, instruction):
+    def enhance_next(self, instruction) -> None:
         """
         Adds a ``next`` field to the instruction.
 
@@ -99,8 +102,7 @@ class DisassemblyAssistant:
             next_addr = instruction.address + instruction.size
             instruction.target = self.next(instruction, call=True)
 
-
-        instruction.next = next_addr & pwndbg.arch.ptrmask
+        instruction.next = next_addr & pwndbg.gdblib.arch.ptrmask
 
         if instruction.target is None:
             instruction.target = instruction.next
@@ -108,7 +110,6 @@ class DisassemblyAssistant:
         if instruction.operands and instruction.operands[0].int:
             instruction.target_const = True
 
-
     def next(self, instruction, call=False):
         """
         Architecture-specific hook point for enhance_next.
@@ -126,10 +127,10 @@ class DisassemblyAssistant:
             return None
 
         # Memory operands must be dereferenced
-        op   = instruction.operands[0]
+        op = instruction.operands[0]
         addr = op.int
         if addr:
-            addr &= pwndbg.arch.ptrmask
+            addr &= pwndbg.gdblib.arch.ptrmask
         if op.type == CS_OP_MEM:
             if addr is None:
                 addr = self.memory(instruction, op)
@@ -139,7 +140,7 @@ class DisassemblyAssistant:
                 try:
                     # fails with gdb.MemoryError if the dereferenced address
                     # doesn't belong to any of process memory maps
-                    addr = int(pwndbg.memory.poi(pwndbg.typeinfo.ppvoid, addr))
+                    addr = int(pwndbg.gdblib.memory.poi(pwndbg.gdblib.typeinfo.ppvoid, addr))
                 except gdb.MemoryError:
                     return None
         if op.type == CS_OP_REG:
@@ -151,7 +152,7 @@ class DisassemblyAssistant:
 
         return int(addr)
 
-    def enhance_symbol(self, instruction):
+    def enhance_symbol(self, instruction) -> None:
         """
         Adds a ``symbol`` and ``symbol_addr`` fields to the instruction.
 
@@ -172,7 +173,7 @@ class DisassemblyAssistant:
         instruction.symbol = o.symbol
         instruction.symbol_addr = o.int
 
-    def enhance_operands(self, instruction):
+    def enhance_operands(self, instruction) -> None:
         """
         Enhances all of the operands in the instruction, by adding the following
         fields:
@@ -188,22 +189,21 @@ class DisassemblyAssistant:
             Resolved symbol name for this operand.
         """
         for i, op in enumerate(instruction.operands):
-            op.int    = None
+            op.int = None
             op.symbol = None
 
             op.int = self.op_handlers.get(op.type, lambda *a: None)(instruction, op)
             if op.int:
-                op.int &= pwndbg.arch.ptrmask
+                op.int &= pwndbg.gdblib.arch.ptrmask
             op.str = self.op_names.get(op.type, lambda *a: None)(instruction, op)
 
             if op.int:
-                op.symbol = pwndbg.symbol.get(op.int)
-
+                op.symbol = pwndbg.gdblib.symbol.get(op.int)
 
     def immediate(self, instruction, operand):
         return operand.value.imm
 
-    def immediate_sz(self, instruction, operand):
+    def immediate_sz(self, instruction, operand) -> str:
         value = operand.int
 
         if abs(value) < 0x10:
@@ -212,53 +212,54 @@ class DisassemblyAssistant:
         return "%#x" % value
 
     def register(self, instruction, operand):
-        if instruction.address != pwndbg.regs.pc:
+        if instruction.address != pwndbg.gdblib.regs.pc:
             return None
 
         # # Don't care about registers which are only overwritten
         # if operand.access & CS_AC_WRITE and not operand.access & CS_AC_READ:
         #     return None
 
-        reg  = operand.value.reg
+        reg = operand.value.reg
         name = instruction.reg_name(reg)
 
-        return pwndbg.regs[name]
+        return pwndbg.gdblib.regs[name]
 
     def register_sz(self, instruction, operand):
-        reg  = operand.value.reg
+        reg = operand.value.reg
         return instruction.reg_name(reg).lower()
 
     def memory(self, instruction, operand):
         return None
 
     def memory_sz(self, instruction, operand):
-        return None # raise NotImplementedError
+        return None  # raise NotImplementedError
 
     def dump(self, instruction):
         """
         Debug-only method.
         """
         ins = instruction
-        rv  = []
-        rv.append('%s %s' % (ins.mnemonic, ins.op_str))
+        rv = []
+        rv.append("%s %s" % (ins.mnemonic, ins.op_str))
 
         for i, group in enumerate(ins.groups):
-            rv.append('   groups[%i]   = %s' % (i, groups.get(group, group)))
+            rv.append("   groups[%i]   = %s" % (i, groups.get(group, group)))
 
-        rv.append('           next = %#x' % (ins.next))
-        rv.append('      condition = %r' % (ins.condition))
+        rv.append("           next = %#x" % (ins.next))
+        rv.append("      condition = %r" % (ins.condition))
 
         for i, op in enumerate(ins.operands):
-            rv.append('   operands[%i] = %s' % (i, ops.get(op.type, op.type)))
-            rv.append('       access   = %s' % (access.get(op.access, op.access)))
+            rv.append("   operands[%i] = %s" % (i, ops.get(op.type, op.type)))
+            rv.append("       access   = %s" % (access.get(op.access, op.access)))
 
             if op.int is not None:
-                rv.append('            int = %#x' % (op.int))
+                rv.append("            int = %#x" % (op.int))
             if op.symbol is not None:
-                rv.append('            sym = %s' % (op.symbol))
+                rv.append("            sym = %s" % (op.symbol))
             if op.str is not None:
-                rv.append('            str = %s' % (op.str))
+                rv.append("            str = %s" % (op.str))
+
+        return "\n".join(rv)
 
-        return '\n'.join(rv)
 
 generic_assistant = DisassemblyAssistant(None)
