@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Given an address in memory which does not contain a pointer elsewhere
 into memory, attempt to describe the data as best as possible.
@@ -11,46 +9,39 @@ supplemental information sources (e.g. active IDA Pro connection).
 
 import string
 
-import gdb
-
-import pwndbg.arch
-import pwndbg.color as color
 import pwndbg.color.enhance as E
-import pwndbg.config
 import pwndbg.disasm
-import pwndbg.memoize
-import pwndbg.memory
-import pwndbg.strings
-import pwndbg.symbol
-import pwndbg.typeinfo
+import pwndbg.gdblib.arch
+import pwndbg.gdblib.config
+import pwndbg.gdblib.memory
+import pwndbg.gdblib.strings
+import pwndbg.gdblib.symbol
+import pwndbg.gdblib.typeinfo
+import pwndbg.lib.memoize
+from pwndbg import color
 from pwndbg.color.syntax_highlight import syntax_highlight
 
-bad_instrs = [
-'.byte',
-'.long',
-'rex.R',
-'rex.XB',
-'.inst',
-'(bad)'
-]
+bad_instrs = [".byte", ".long", "rex.R", "rex.XB", ".inst", "(bad)"]
 
-def good_instr(i):
+
+def good_instr(i) -> bool:
     return not any(bad in i for bad in bad_instrs)
 
-def int_str(value):
-    retval = '%#x' % int(value & pwndbg.arch.ptrmask)
+
+def int_str(value: int) -> str:
+    retval = "%#x" % int(value & pwndbg.gdblib.arch.ptrmask)
 
     # Try to unpack the value as a string
-    packed = pwndbg.arch.pack(int(value))
-    if all(c in string.printable.encode('utf-8') for c in packed):
+    packed = pwndbg.gdblib.arch.pack(int(value))
+    if all(c in string.printable.encode("utf-8") for c in packed):
         if len(retval) > 4:
-            retval = '%s (%r)' % (retval, str(packed.decode('ascii', 'ignore')))
+            retval = "%s (%r)" % (retval, str(packed.decode("ascii", "ignore")))
 
     return retval
 
 
-# @pwndbg.memoize.reset_on_stop
-def enhance(value, code = True, safe_linking = False):
+# @pwndbg.lib.memoize.reset_on_stop
+def enhance(value: int, code: bool = True, safe_linking: bool = False) -> str:
     """
     Given the last pointer in a chain, attempt to characterize
 
@@ -68,13 +59,13 @@ def enhance(value, code = True, safe_linking = False):
     """
     value = int(value)
 
-    name = pwndbg.symbol.get(value) or None
-    page = pwndbg.vmmap.find(value)
+    name = pwndbg.gdblib.symbol.get(value) or None
+    page = pwndbg.gdblib.vmmap.find(value)
 
     # If it's not in a page we know about, try to dereference
     # it anyway just to test.
     can_read = True
-    if not page or None == pwndbg.memory.peek(value):
+    if not page or None is pwndbg.gdblib.memory.peek(value):
         can_read = False
 
     if not can_read:
@@ -82,13 +73,13 @@ def enhance(value, code = True, safe_linking = False):
 
     # It's mapped memory, or we can at least read it.
     # Try to find out if it's a string.
-    instr  = None
-    exe    = page and page.execute
-    rwx    = page and page.rwx
+    instr = None
+    exe = page and page.execute
+    rwx = page and page.rwx
 
     # For the purpose of following pointers, don't display
     # anything on the stack or heap as 'code'
-    if '[stack' in page.objfile or '[heap' in page.objfile:
+    if "[stack" in page.objfile or "[heap" in page.objfile:
         rwx = exe = False
 
     # If IDA doesn't think it's in a function, don't display it as code.
@@ -98,27 +89,27 @@ def enhance(value, code = True, safe_linking = False):
     if exe:
         instr = pwndbg.disasm.one(value)
         if instr:
-            instr = "%-6s %s" % (instr.mnemonic, instr.op_str)
-            if pwndbg.config.syntax_highlight:
+            instr = "%s %s" % (instr.mnemonic, instr.op_str)
+            if pwndbg.gdblib.config.syntax_highlight:
                 instr = syntax_highlight(instr)
 
-    szval = pwndbg.strings.get(value) or None
+    szval = pwndbg.gdblib.strings.get(value) or None
     szval0 = szval
     if szval:
         szval = E.string(repr(szval))
 
     # Fix for case when we can't read the end address anyway (#946)
-    if value + pwndbg.arch.ptrsize > page.end:
+    if value + pwndbg.gdblib.arch.ptrsize > page.end:
         return E.integer(int_str(value))
 
-    intval  = int(pwndbg.memory.poi(pwndbg.typeinfo.pvoid, value))
+    intval = int(pwndbg.gdblib.memory.poi(pwndbg.gdblib.typeinfo.pvoid, value))
     if safe_linking:
         intval ^= value >> 12
     intval0 = intval
     if 0 <= intval < 10:
         intval = E.integer(str(intval))
     else:
-        intval = E.integer('%#x' % int(intval & pwndbg.arch.ptrmask))
+        intval = E.integer("%#x" % int(intval & pwndbg.gdblib.arch.ptrmask))
 
     retval = []
 
@@ -127,11 +118,9 @@ def enhance(value, code = True, safe_linking = False):
         instr = None
 
     # If it's on the stack, don't display it as code in a chain.
-    if instr and 'stack' in page.objfile:
+    if instr and "stack" in page.objfile:
         retval = [intval, szval]
 
-
-
     # If it's RWX but a small value, don't display it as code in a chain.
     elif instr and rwx and intval0 < 0x1000:
         retval = [intval, szval]
@@ -148,7 +137,7 @@ def enhance(value, code = True, safe_linking = False):
 
     # Otherwise strings have preference
     elif szval:
-        if len(szval0) < pwndbg.arch.ptrsize:
+        if len(szval0) < pwndbg.gdblib.arch.ptrsize:
             retval = [intval, szval]
         else:
             retval = [szval]
@@ -165,4 +154,4 @@ def enhance(value, code = True, safe_linking = False):
     if len(retval) == 1:
         return retval[0]
 
-    return retval[0] + E.comment(color.strip(' /* {} */'.format('; '.join(retval[1:]))))
+    return retval[0] + E.comment(color.strip(" /* {} */".format("; ".join(retval[1:]))))
