@@ -1,16 +1,17 @@
 from subprocess import CalledProcessError
 
 import pwndbg.commands
-import pwndbg.memoize
+import pwndbg.lib.memoize
 import pwndbg.wrappers
 
 cmd_name = "checksec"
 cmd_pwntools = ["pwn", "checksec"]
 
+
 @pwndbg.wrappers.OnlyWithCommand(cmd_name, cmd_pwntools)
-@pwndbg.memoize.reset_on_objfile
+@pwndbg.lib.memoize.reset_on_objfile
 def get_raw_out():
-    local_path = pwndbg.file.get_file(pwndbg.proc.exe)
+    local_path = pwndbg.gdblib.file.get_proc_exe_file()
     try:
         return pwndbg.wrappers.call_cmd(get_raw_out.cmd + ["--file=" + local_path])
     except CalledProcessError:
@@ -21,6 +22,7 @@ def get_raw_out():
         pass
     return pwndbg.wrappers.call_cmd(get_raw_out.cmd + [local_path])
 
+
 @pwndbg.wrappers.OnlyWithCommand(cmd_name, cmd_pwntools)
 def relro_status():
     relro = "No RELRO"
@@ -33,6 +35,7 @@ def relro_status():
 
     return relro
 
+
 @pwndbg.wrappers.OnlyWithCommand(cmd_name, cmd_pwntools)
 def pie_status():
     pie = "No PIE"
